@@ -20,6 +20,7 @@ import (
 func (root *Root) toggleWrapMode(context.Context) {
 	m := root.Doc
 	m.WrapMode = !m.WrapMode
+	root.resetSelect()
 
 	// Move cursor to correct position
 	x, err := m.optimalX(root.scr, m.columnCursor)
@@ -84,11 +85,13 @@ func (root *Root) toggleRainbow(context.Context) {
 // toggleFollowMode toggles follow mode.
 func (root *Root) toggleFollowMode(context.Context) {
 	root.Doc.FollowMode = !root.Doc.FollowMode
+	root.Doc.pauseFollow = false
 }
 
 // toggleFollowAll toggles follow all mode.
 func (root *Root) toggleFollowAll(context.Context) {
 	root.FollowAll = !root.FollowAll
+	root.Doc.pauseFollow = false
 	root.mu.Lock()
 	for _, doc := range root.DocList {
 		doc.latestNum = doc.BufEndNum()
@@ -98,6 +101,7 @@ func (root *Root) toggleFollowAll(context.Context) {
 
 // toggleFollowSection toggles follow section mode.
 func (root *Root) toggleFollowSection(context.Context) {
+	root.Doc.pauseFollow = false
 	root.Doc.FollowSection = !root.Doc.FollowSection
 }
 
@@ -120,6 +124,16 @@ func (root *Root) toggleMouse(context.Context) {
 	}
 }
 
+// toggleStatusLine toggles the status line visibility.
+func (root *Root) toggleStatusLine(context.Context) {
+	root.Doc.StatusLine = !root.Doc.StatusLine
+	if root.Doc.StatusLine {
+		root.setMessage("Status Line visible")
+	} else {
+		root.setMessage("Status Line hidden")
+	}
+}
+
 // toggleRuler cycles through the ruler types (None, Relative, Absolute) each time it is called.
 func (root *Root) toggleRuler(ctx context.Context) {
 	switch root.Doc.RulerType {
@@ -131,6 +145,7 @@ func (root *Root) toggleRuler(ctx context.Context) {
 		root.Doc.RulerType = RulerNone
 	}
 	root.setMessagef("Set Ruler %s", root.Doc.RulerType.String())
+	root.resetSelect()
 	root.ViewSync(ctx)
 }
 
@@ -158,7 +173,7 @@ func (root *Root) reload(m *Document) {
 // toggleWatch toggles watch mode.
 func (root *Root) toggleWatch(context.Context) {
 	if root.Doc.WatchMode {
-		root.Doc.unWatchMode()
+		root.Doc.unwatchMode()
 	} else {
 		root.Doc.watchMode()
 	}
@@ -198,6 +213,7 @@ func (root *Root) watchControl() {
 // searchGo will go to the line with the matching term after searching.
 // Jump by section if JumpTargetSection is true.
 func (root *Root) searchGo(ctx context.Context, lN int, searcher Searcher) {
+	root.setPauseFollow()
 	root.resetSelect()
 	root.Doc.lastSearchLN = lN
 	start, end := root.searchXPos(lN, searcher)
@@ -280,7 +296,7 @@ func (root *Root) addMark(context.Context) {
 	lN := root.firstBodyLine()
 	root.Doc.marked = remove(root.Doc.marked, lN)
 	root.Doc.marked = append(root.Doc.marked, lN)
-	root.Doc.markedPoint++
+	root.Doc.markedPoint = len(root.Doc.marked) - 1
 	root.setMessagef("Marked to line %d", lN-root.Doc.firstLine()+1)
 }
 
@@ -409,18 +425,15 @@ func (root *Root) subShell(shell string) error {
 	if shell == "" {
 		shell = getShell()
 	}
-
 	stdin := os.Stdin
-	if !term.IsTerminal(int(os.Stdin.Fd())) {
-		// Use TTY as stdin when the current stdin is not a terminal.
-		tty, err := getTty()
+	if !term.IsTerminal(int(stdin.Fd())) {
+		tty, err := getTTY()
 		if err != nil {
-			return fmt.Errorf("failed to open tty: %w", err)
+			return fmt.Errorf("failed to get stdin: %w", err)
 		}
 		defer tty.Close()
 		stdin = tty
 	}
-
 	c := exec.Command(shell, "-l")
 	c.Stdin = stdin
 	c.Stdout = os.Stdout
@@ -432,20 +445,6 @@ func (root *Root) subShell(shell string) error {
 	return nil
 }
 
-func getShell() string {
-	if runtime.GOOS == "windows" {
-		return "CMD.EXE"
-	}
-	return "/bin/sh"
-}
-
-func getTty() (*os.File, error) {
-	if runtime.GOOS == "windows" {
-		return os.Open("CONIN$")
-	}
-	return os.Open("/dev/tty")
-}
-
 // setViewMode switches to the preset display mode.
 func (root *Root) setViewMode(ctx context.Context, modeName string) {
 	if modeName == "" {
@@ -558,7 +557,7 @@ func (root *Root) setWatchInterval(input string) {
 
 	root.Doc.WatchInterval = interval
 	if root.Doc.WatchInterval == 0 {
-		root.Doc.unWatchMode()
+		root.Doc.unwatchMode()
 	} else {
 		root.Doc.watchMode()
 	}
@@ -763,13 +762,18 @@ func calculatePosition(str string, length int) (float64, error) {
 
 // TailSync move to tail and sync.
 func (root *Root) TailSync(ctx context.Context) {
-	root.Doc.moveBottom()
+	if !root.Doc.pauseFollow {
+		root.Doc.moveBottom()
+	}
 	root.ViewSync(ctx)
 }
 
 // tailSection moves to the last section
 // and adjusts to its original position.
 func (root *Root) tailSection(ctx context.Context) {
+	if root.Doc.pauseFollow {
+		return
+	}
 	moved := root.Doc.topLN - root.Doc.lastSectionPosNum
 	root.Doc.moveLastSection(ctx)
 	if moved > 0 && (root.Doc.topLN+moved) < root.Doc.BufEndNum() {
@@ -851,6 +855,12 @@ func (root *Root) toggleWriteOriginal(context.Context) {
 
 // WriteQuit sets the write flag and executes a quit event.
 func (root *Root) WriteQuit(ctx context.Context) {
+	if root.Doc.documentType == DocHelp || root.Doc.documentType == DocLog {
+		log.Println("WriteQuit: not a normal document")
+		root.Quit(ctx)
+		return
+	}
+
 	root.Config.IsWriteOnExit = true
 	if root.Doc.HideOtherSection && root.Config.AfterWriteOriginal == 0 {
 		// hide other section.
@@ -959,3 +969,19 @@ func (m *Document) isValidColumn(cursor int) error {
 	}
 	return nil
 }
+
+// setPauseFollow sets pauseFollow to true if sticky follow is not disabled.
+func (root *Root) setPauseFollow() {
+	// If sticky follow is disabled, do nothing.
+	if root.Config.DisableStickyFollow {
+		return
+	}
+	// If already paused, do nothing.
+	if root.Doc.pauseFollow {
+		return
+	}
+	if root.FollowAll || root.Doc.FollowMode || root.Doc.FollowSection {
+		root.Doc.pauseFollow = true
+		root.Doc.pauseLastNum = max(root.Doc.BufEndNum()-1, 0)
+	}
+}
