@@ -168,9 +168,10 @@ func (st *parseState) parseChar(mainc rune, combc []rune) {
 
 // overstrike set style for overstrike.
 func (st *parseState) overstrike(m content, style tcell.Style) tcell.Style {
-	if st.bsContent.mainc == m.mainc {
+	switch st.bsContent.mainc {
+	case m.mainc:
 		style = OverStrikeStyle
-	} else if st.bsContent.mainc == '_' {
+	case '_':
 		style = OverLineStyle
 	}
 	st.bsFlag = false
@@ -227,7 +228,7 @@ func (st *parseState) tabHandle() {
 	st.lc = append(st.lc, c)
 	st.tabx++
 	c.mainc = 0
-	for i := 0; i < tabStop-1; i++ {
+	for range tabStop - 1 {
 		st.lc = append(st.lc, c)
 		st.tabx++
 	}
@@ -298,6 +299,28 @@ func ContentsToStr(lc contents) (string, widthPos) {
 	return str, pos
 }
 
+// String returns a string representation of the contents.
+func (lc contents) String() string {
+	str, _ := ContentsToStr(lc)
+	return str
+}
+
+// IsSpace returns true if the specified position is a space character.
+func (lc contents) IsSpace(n int) bool {
+	if n >= len(lc) {
+		return false
+	}
+	return lc[n].mainc == ' '
+}
+
+// IsFullWidth returns true if the specified position is a full-width character.
+func (lc contents) IsFullWidth(n int) bool {
+	if n >= len(lc) {
+		return false
+	}
+	return lc[n].width == 2
+}
+
 // writeRune writes a rune to strings.Builder.
 func writeRune(w *strings.Builder, r rune) int {
 	n, err := w.WriteRune(r)
@@ -310,6 +333,9 @@ func writeRune(w *strings.Builder, r rune) int {
 // x returns the x position on the screen.
 // [n]byte -> x.
 func (pos widthPos) x(n int) int {
+	if n < 0 {
+		return 0
+	}
 	if n < len(pos) {
 		return pos[n]
 	}
@@ -318,10 +344,12 @@ func (pos widthPos) x(n int) int {
 
 // n return string position from content.
 // x -> [n]byte.
-func (pos widthPos) n(w int) int {
-	x := w
+func (pos widthPos) n(x int) int {
+	if x < 0 {
+		return 0
+	}
 	for _, c := range pos {
-		if c >= w {
+		if c >= x {
 			x = c
 			break
 		}
