@@ -36,14 +36,13 @@ func TestDocument_Write(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 			l, err := NewLogDoc()
 			if err != nil {
 				t.Fatal(err)
 			}
-			for i := 0; i < tt.repeat; i++ {
+			for range tt.repeat {
 				got, err := l.Write(tt.args.log)
 				if (err != nil) != tt.wantErr {
 					t.Errorf("Document.Write() error = %v, wantErr %v", err, tt.wantErr)
