@@ -90,8 +90,19 @@ type Root struct {
 	FollowAll bool
 	// skipDraw is set to true when the mouse cursor just moves (no event occurs).
 	skipDraw bool
+	// clickState is the state of mouse click.
+	clickState ClickState
 }
 
+// MouseSelectState represents the state of mouse selection.
+type MouseSelectState int
+
+const (
+	SelectNone   MouseSelectState = iota // no selection
+	SelectActive                         // selecting
+	SelectCopied                         // selection copied
+)
+
 // SCR contains the screen information.
 type SCR struct {
 	// lines is the lines of the screen.
@@ -131,7 +142,7 @@ type SCR struct {
 	x2 int
 	y2 int
 	// mouseSelect is a flag with mouse selection.
-	mouseSelect bool
+	mouseSelect MouseSelectState
 	// mousePressed is a flag when the mouse selection button is pressed.
 	mousePressed bool
 	// mouseRectangle is a flag for rectangle selection.
@@ -218,6 +229,8 @@ type RunTimeSettings struct {
 	HScrollWidth string
 	// HScrollWidthNum is the horizontal scroll width.
 	HScrollWidthNum int
+	// VScrollLines is the number of lines to scroll with the mouse wheel.
+	VScrollLines int
 	// RulerType is the ruler type (0: none, 1: relative, 2: absolute).
 	RulerType RulerType
 	// AlternateRows alternately style rows.
@@ -296,6 +309,12 @@ type Style struct {
 	LeftStatus OVStyle
 	// RightStatus is the style that applies to the right status line.
 	RightStatus OVStyle
+	// SelectActive is the style that applies to the text being selected (during mouse drag).
+	SelectActive OVStyle
+	// SelectCopied is the style that applies to the text that has been copied to clipboard.
+	SelectCopied OVStyle
+	// PauseLine is the style that applies to the line where follow mode is paused.
+	PauseLine OVStyle
 }
 
 var (
@@ -412,6 +431,13 @@ var (
 // This is a function of tcell.NewScreen but can be replaced with mock.
 var tcellNewScreen = tcell.NewScreen
 
+// SetTcellNewScreen sets the function to create a new tcell screen.
+// This is used for testing purposes to replace the tcell.NewScreen function.
+// It allows for mocking the screen creation in tests.
+func SetTcellNewScreen(f func() (tcell.Screen, error)) {
+	tcellNewScreen = f
+}
+
 // NewOviewer return the structure of oviewer.
 // NewOviewer requires one or more documents.
 func NewOviewer(docs ...*Document) (*Root, error) {
@@ -456,6 +482,7 @@ func NewRunTimeSettings() RunTimeSettings {
 		OVPromptConfig: NewOVPromptConfig(),
 		Style:          NewStyle(),
 		StatusLine:     true,
+		VScrollLines:   2,
 	}
 }
 
@@ -513,6 +540,15 @@ func NewStyle() Style {
 			Foreground: "#CCCCCC",
 			Bold:       true,
 		},
+		SelectActive: OVStyle{
+			Reverse: true,
+		},
+		SelectCopied: OVStyle{
+			Background: "slategrey",
+		},
+		PauseLine: OVStyle{
+			Background: "#663333",
+		},
 	}
 }
 
@@ -746,12 +782,6 @@ func (root *Root) Run() error {
 		return err
 	}
 
-	// Quit if fits on screen.
-	if root.Config.QuitSmall && root.DocumentLen() == 1 && root.docSmall() {
-		root.Config.IsWriteOnExit = true
-		return nil
-	}
-
 	sigs := make(chan os.Signal, 1)
 	signal.Notify(sigs, os.Interrupt, syscall.SIGTERM, syscall.SIGHUP, syscall.SIGINT)
 	sigSuspend := registerSIGTSTP()
@@ -806,6 +836,11 @@ func (root *Root) prepareRun(ctx context.Context) error {
 
 	root.setViewModeConfig()
 	root.prepareAllDocuments()
+	// follow mode or follow all disables quit if the output fits on one screen.
+	if root.Doc.FollowMode || root.FollowAll {
+		root.Config.QuitSmall = false
+		root.Config.QuitSmallFilter = false
+	}
 	// Quit by filter result. This is evaluated lazily.
 	if root.Config.QuitSmallFilter {
 		root.quitSmallCountDown = QuitSmallCountDown
@@ -842,6 +877,7 @@ func (root *Root) setViewModeConfig() {
 func (root *Root) prepareAllDocuments() {
 	for n, doc := range root.DocList {
 		doc.RunTimeSettings = root.settings
+		doc.RunTimeSettings = updateRunTimeSettings(doc.RunTimeSettings, doc.General)
 		doc.regexpCompile()
 
 		if doc.FollowName {
@@ -1024,6 +1060,9 @@ func updateRunTimeSettings(src RunTimeSettings, dst General) RunTimeSettings {
 	if dst.HScrollWidthNum != nil {
 		src.HScrollWidthNum = *dst.HScrollWidthNum
 	}
+	if dst.VScrollLines != nil {
+		src.VScrollLines = *dst.VScrollLines
+	}
 	if dst.RulerType != nil {
 		src.RulerType = *dst.RulerType
 	}
@@ -1174,6 +1213,15 @@ func updateRuntimeStyle(src Style, dst StyleConfig) Style {
 	if dst.RightStatus != nil {
 		src.RightStatus = *dst.RightStatus
 	}
+	if dst.SelectActive != nil {
+		src.SelectActive = *dst.SelectActive
+	}
+	if dst.SelectCopied != nil {
+		src.SelectCopied = *dst.SelectCopied
+	}
+	if dst.PauseLine != nil {
+		src.PauseLine = *dst.PauseLine
+	}
 	return src
 }
 
@@ -1184,6 +1232,7 @@ func (root *Root) docSmall() bool {
 	if !m.BufEOF() {
 		return false
 	}
+	screenHeight := root.scr.vHeight - root.scr.statusLineHeight
 	height := 0
 	for y := range m.BufEndNum() {
 		lc, err := m.contents(y)
@@ -1192,7 +1241,7 @@ func (root *Root) docSmall() bool {
 			continue
 		}
 		height += 1 + (len(lc) / root.scr.vWidth)
-		if height > root.scr.vHeight {
+		if height > screenHeight {
 			return false
 		}
 	}
@@ -1240,7 +1289,7 @@ func (root *Root) writeCurrentScreen(output io.Writer) {
 			log.Println(err)
 			return
 		}
-		strs = tcellansi.ScreenContentToStrings(root.Screen, 0, root.Doc.width, 0, height-root.scr.statusLineHeight)
+		strs = tcellansi.ScreenContentToStrings(root.Screen, 0, root.Doc.width, 0, height)
 		strs = tcellansi.TrimRightSpaces(strs)
 	}
 	for _, str := range strs {
@@ -1264,7 +1313,7 @@ func (root *Root) dummyScreen() (int, error) {
 		if root.Config.AfterWriteOriginal != 0 {
 			end = root.Doc.topLN + root.Config.AfterWriteOriginal
 		}
-		height = end - root.Doc.topLN
+		height = max(end-root.Doc.topLN, 0)
 	}
 	root.Screen.SetSize(root.scr.vWidth, height)
 	if root.Pattern != "" {
@@ -1274,7 +1323,7 @@ func (root *Root) dummyScreen() (int, error) {
 	root.prepareScreen()
 	root.prepareDraw(ctx)
 	root.draw(ctx)
-	height = realHeight(root.scr) + 1
+	height = realHeight(root.scr)
 	return height, nil
 }
 
@@ -1360,6 +1409,17 @@ func (scr SCR) lineNumber(y int) LineNumber {
 	return scr.numbers[0]
 }
 
+// lineY returns the screen y position for a given LineNumber.
+// If not found, returns -1.
+func (scr SCR) lineY(ln LineNumber) int {
+	for y, num := range scr.numbers {
+		if num == ln {
+			return y
+		}
+	}
+	return -1
+}
+
 // debugNumOfChunk outputs the number of chunks.
 func (root *Root) debugNumOfChunk() {
 	if !root.Config.Debug {
